@@ -58,6 +58,7 @@ func runCmd(config *dao.Config, configErr *error) *cobra.Command {
 			setRunFlags.All = cmd.Flags().Changed("all")
 			setRunFlags.AnyErrorsFatal = cmd.Flags().Changed("any-errors-fatal")
 			setRunFlags.Attach = cmd.Flags().Changed("attach")
+			setRunFlags.Forks = cmd.Flags().Changed("forks")
 			setRunFlags.Batch = cmd.Flags().Changed("batch")
 			setRunFlags.BatchP = cmd.Flags().Changed("batch-p")
 			setRunFlags.Describe = cmd.Flags().Changed("describe")
@@ -80,29 +81,62 @@ func runCmd(config *dao.Config, configErr *error) *cobra.Command {
 			setRunFlags.TTY = cmd.Flags().Changed("tty")
 			setRunFlags.Tags = cmd.Flags().Changed("tags")
 			setRunFlags.Verbose = cmd.Flags().Changed("verbose")
+			setRunFlags.MaxFailPercentage = cmd.Flags().Changed("max-fail-percentage")
 
-			maxFailPercentage, err := cmd.Flags().GetUint8("max-fail-percentage")
-			core.CheckIfError(err)
-			runFlags.MaxFailPercentage = maxFailPercentage
+			if setRunFlags.MaxFailPercentage {
+				maxFailPercentage, err := cmd.Flags().GetUint8("max-fail-percentage")
+				core.CheckIfError(err)
+				if maxFailPercentage > 100 {
+					core.Exit(&core.InvalidPercentInput{Name: "max-fail-percentage"})
+				}
+				runFlags.MaxFailPercentage = maxFailPercentage
+			}
 
-			forks, err := cmd.Flags().GetUint32("forks")
-			core.CheckIfError(err)
-			runFlags.Forks = forks
+			if setRunFlags.Forks {
+				forks, err := cmd.Flags().GetUint32("forks")
+				core.CheckIfError(err)
+				if forks == 0 {
+					core.Exit(&core.ZeroNotAllowed{Name: "forks"})
+				}
+				runFlags.Forks = forks
+			}
 
-			batch, err := cmd.Flags().GetUint32("batch")
-			core.CheckIfError(err)
-			batchp, err := cmd.Flags().GetUint8("batch-p")
-			core.CheckIfError(err)
-			runFlags.Batch = batch
-			runFlags.BatchP = batchp
+			if setRunFlags.Batch {
+				batch, err := cmd.Flags().GetUint32("batch")
+				core.CheckIfError(err)
+				if batch == 0 {
+					core.Exit(&core.ZeroNotAllowed{Name: "batch"})
+				}
+				runFlags.Batch = batch
+			}
 
-			limit, err := cmd.Flags().GetUint32("limit")
-			core.CheckIfError(err)
-			limitp, err := cmd.Flags().GetUint8("limit-p")
-			core.CheckIfError(err)
+			if setRunFlags.BatchP {
+				batchp, err := cmd.Flags().GetUint8("batch-p")
+				core.CheckIfError(err)
+				if batchp == 0 || batchp > 100 {
+					core.Exit(&core.InvalidPercentInput2{Name: "batch-p"})
+				}
+				runFlags.BatchP = batchp
+			}
 
-			runFlags.Limit = limit
-			runFlags.LimitP = limitp
+			if setRunFlags.Limit {
+				limit, err := cmd.Flags().GetUint32("limit")
+				core.CheckIfError(err)
+				if limit == 0 {
+					core.Exit(&core.ZeroNotAllowed{Name: "limit"})
+				}
+				runFlags.Limit = limit
+			}
+
+			// Min-limit-p 1
+			if setRunFlags.LimitP {
+				limitp, err := cmd.Flags().GetUint8("limit-p")
+				core.CheckIfError(err)
+				if limitp == 0 || limitp > 100 {
+					core.Exit(&core.InvalidPercentInput2{Name: "limit-p"})
+				}
+				runFlags.LimitP = limitp
+			}
 
 			runTask(args, config, &runFlags, &setRunFlags)
 		},
@@ -212,6 +246,16 @@ func runCmd(config *dao.Config, configErr *error) *cobra.Command {
 	})
 	core.CheckIfError(err)
 
+	cmd.Flags().StringVarP(&runFlags.Print, "print", "p", "", "set print [all|stdout|stderr]")
+	err = cmd.RegisterFlagCompletionFunc("print", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		if *configErr != nil {
+			return []string{}, cobra.ShellCompDirectiveDefault
+		}
+		valid := []string{"all", "stdout", "stderr"}
+		return valid, cobra.ShellCompDirectiveDefault
+	})
+	core.CheckIfError(err)
+
 	cmd.Flags().BoolVar(&runFlags.OmitEmptyRows, "omit-empty-rows", false, "omit empty row for table output")
 	cmd.Flags().BoolVar(&runFlags.OmitEmptyColumns, "omit-empty-columns", false, "omit empty column for table output")
 	cmd.Flags().BoolVarP(&runFlags.Silent, "silent", "q", false, "omit showing loader when running tasks")
