@@ -19,6 +19,8 @@ var (
 
 	DEFAULT_SHELL = "bash -c"
 
+	DEFAULT_TIMEOUT = uint(20)
+
 	DEFAULT_THEME = Theme{
 		Name:  "default",
 		Table: DefaultTable,
@@ -43,26 +45,29 @@ var (
 		ListHosts:         false,
 		Order:             "inventory",
 		Silent:            false,
+		Hidden:            false,
 		Strategy:          "linear",
-		Output:            "text",
+		Batch:             0,
+		BatchP:            0,
 		Forks:             10000,
+		Output:            "text",
 		MaxFailPercentage: 0,
 		AnyErrorsFatal:    true,
 		IgnoreErrors:      false,
 		IgnoreUnreachable: false,
 		OmitEmptyRows:     false,
 		OmitEmptyColumns:  false,
-		Batch:             0,
-		BatchP:            0,
 		Report:            []string{"recap"},
 		Verbose:           false,
 		Confirm:           false,
 		Step:              false,
+		Print:             "all",
 	}
 )
 
 type Config struct {
 	SSHConfigFile     *string
+	DefaultTimeout    uint
 	DisableVerifyHost bool
 	KnownHostsFile    string
 	Shell             string
@@ -83,6 +88,7 @@ type ConfigYAML struct {
 
 	// Intermediate
 	DisableVerifyHost *bool     `yaml:"disable_verify_host"`
+	DefaultTimeout    *uint     `yaml:"default_timeout"`
 	KnownHostsFile    *string   `yaml:"known_hosts_file"`
 	Shell             string    `yaml:"shell"`
 	Import            yaml.Node `yaml:"import"`
@@ -109,7 +115,11 @@ func ReadConfig(configFilepath string, userConfigPath string, sshConfigFile stri
 	CheckUserNoColor(noColor)
 	var configPath string
 
-	userConfigFile := getUserConfigFile(userConfigPath)
+	userConfigFile, err := getUserConfigFile(userConfigPath)
+	if err != nil {
+		return Config{}, err
+	}
+
 	sshConfigPath, err := getSSHConfigPath(sshConfigFile)
 	if err != nil {
 		return Config{}, err
@@ -179,28 +189,38 @@ func ReadConfig(configFilepath string, userConfigPath string, sshConfigFile stri
 	return config, nil
 }
 
-func getUserConfigFile(userConfigPath string) *string {
+func getUserConfigFile(userConfigPath string) (*string, error) {
 	// Flag
 	if userConfigPath != "" {
-		if _, err := os.Stat(userConfigPath); err == nil {
-			return &userConfigPath
+		if _, err := os.Stat(userConfigPath); err != nil {
+			return nil, fmt.Errorf("user config not found: %w", err)
 		}
+		return &userConfigPath, nil
 	}
 
 	// Env
 	val, present := os.LookupEnv("SAKE_USER_CONFIG")
 	if present {
-		return &val
+		if _, err := os.Stat(val); err != nil {
+			return nil, fmt.Errorf("user config not found: %w", err)
+		}
+		return &val, nil
 	}
 
 	// Default
 	defaultUserConfigDir, _ := os.UserConfigDir()
+
 	defaultUserConfigPath := filepath.Join(defaultUserConfigDir, "sake", "config.yaml")
 	if _, err := os.Stat(defaultUserConfigPath); err == nil {
-		return &defaultUserConfigPath
+		return &defaultUserConfigPath, nil
 	}
 
-	return nil
+	defaultUserConfigPath = filepath.Join(defaultUserConfigDir, "sake", "config.yml")
+	if _, err := os.Stat(defaultUserConfigPath); err == nil {
+		return &defaultUserConfigPath, nil
+	}
+
+	return nil, nil
 }
 
 func getSSHConfigPath(sshConfigPath string) (*string, error) {
