@@ -18,6 +18,7 @@ type Spec struct {
 	ListHosts         bool     `yaml:"list_hosts"`
 	Order             string   `yaml:"order"`
 	Silent            bool     `yaml:"silent"`
+	Hidden            bool     `yaml:"hidden"`
 	Strategy          string   `yaml:"strategy"`
 	Batch             uint32   `yaml:"batch"`
 	BatchP            uint8    `yaml:"batch_p"`
@@ -33,6 +34,7 @@ type Spec struct {
 	Verbose           bool     `yaml:"verbose"`
 	Confirm           bool     `yaml:"confirm"`
 	Step              bool     `yaml:"step"`
+	Print             string   `yaml:"print"`
 
 	context     string // config path
 	contextLine int    // defined at
@@ -53,12 +55,22 @@ func (s Spec) GetValue(key string, _ int) string {
 		return s.Name
 	case "desc", "Desc":
 		return s.Desc
+	case "print", "Print":
+		return s.Print
 	case "describe", "Describe":
 		return strconv.FormatBool(s.Describe)
 	case "list_hosts":
 		return strconv.FormatBool(s.ListHosts)
 	case "silent", "Silent":
 		return strconv.FormatBool(s.Silent)
+	case "hidden", "Hidden":
+		return strconv.FormatBool(s.Hidden)
+	case "verbose", "Verbose":
+		return strconv.FormatBool(s.Verbose)
+	case "confirm", "Confirm":
+		return strconv.FormatBool(s.Confirm)
+	case "step", "Step":
+		return strconv.FormatBool(s.Step)
 	case "strategy":
 		return s.Strategy
 	case "forks":
@@ -127,6 +139,14 @@ func (c *ConfigYAML) DecodeSpec(name string, specYAML yaml.Node) (*Spec, []error
 		specErrors = append(specErrors, &core.MultipleFailSet{Name: name})
 	}
 
+	if spec.MaxFailPercentage > 100 {
+		specErrors = append(specErrors, &core.InvalidPercentInput{Name: "max_fail_percentage"})
+	}
+
+	if spec.Forks == 0 {
+		spec.Forks = 10000
+	}
+
 	if spec.BatchP > 0 && spec.Batch > 0 {
 		specErrors = append(specErrors, &core.BatchMultipleDef{Name: name})
 	}
