@@ -7,7 +7,7 @@ import (
 )
 
 type Client interface {
-	Connect(SSHDialFunc, bool, string, *sync.Mutex) *ErrConnect
+	Connect(SSHDialFunc, bool, string, uint, *sync.Mutex) *ErrConnect
 	Run(int, []string, string, string, string) error
 	Wait(int) error
 	Close(int) error
@@ -18,7 +18,7 @@ type Client interface {
 	Stdout(int) io.Reader
 	Signal(int, os.Signal) error
 	GetName() string
-	Prefix() string
+	Prefix() (string, string, string, uint16)
 	Connected() bool
 }
 
