@@ -41,15 +41,30 @@ func (run *Run) Table(dryRun bool) (dao.TableOutput, dao.ReportData, error) {
 		data.Headers = append(data.Headers, subTask.Name)
 		reportData.Headers = append(reportData.Headers, subTask.Name)
 	}
+
 	// Populate the rows (server name is first cell, then commands and cmd output is set to empty string)
 	for i, p := range servers {
-		data.Rows = append(data.Rows, dao.Row{Columns: []string{p.Host}})
-		reportData.Tasks = append(reportData.Tasks, dao.ReportRow{Name: p.Host, Rows: []dao.Report{}})
+
+		var client Client
+		if p.Local {
+			client = run.LocalClients[p.Name]
+		} else {
+			client = run.RemoteClients[p.Name]
+		}
+
+		title, err := getServerTitle(client, i, task.Theme.Table)
+		if err != nil {
+			return data, reportData, err
+		}
+		// p.Host
+		data.Rows = append(data.Rows, dao.Row{Columns: []string{title}})
+		reportData.Tasks = append(reportData.Tasks, dao.ReportRow{Name: title, Rows: []dao.Report{}})
 		for range task.Tasks {
 			data.Rows[i].Columns = append(data.Rows[i].Columns, "")
 			reportData.Tasks[i].Rows = append(reportData.Tasks[i].Rows, dao.Report{})
 		}
 	}
+
 	k := len(servers)
 	for i, p := range uServers {
 		reportData.Tasks = append(reportData.Tasks, dao.ReportRow{Name: p.Host, Rows: []dao.Report{}})
@@ -480,7 +495,7 @@ func (run *Run) tableWork(
 		client = run.RemoteClients[r.Server.Name]
 	}
 
-	shell := dao.SelectFirstNonEmpty(r.Task.Shell, r.Server.Shell, run.Config.Shell)
+	shell := dao.SelectFirstNonEmpty((*r.Cmd).Shell, r.Task.Shell, r.Server.Shell, run.Config.Shell)
 	shell = core.FormatShell(shell)
 	workDir := getWorkDir((*r.Cmd).Local, (*r.Server).Local, (*r.Cmd).WorkDir, (*r.Server).WorkDir, (*r.Cmd).RootDir, (*r.Server).RootDir)
 	t := TaskContext{
@@ -492,7 +507,7 @@ func (run *Run) tableWork(
 		workDir: workDir,
 		shell:   shell,
 		cmd:     r.Cmd.Cmd,
-		tty:     r.Task.TTY,
+		tty:     r.Cmd.TTY,
 	}
 
 	start := time.Now()
@@ -512,9 +527,23 @@ func (run *Run) tableWork(
 	// out, err := io.ReadAll(client.Stderr())
 	// dataMutex.Unlock()
 	if err != nil {
-		data.Rows[t.rIndex].Columns[t.cIndex] = fmt.Sprintf("%s\n%s", out, err.Error())
+		switch r.Task.Spec.Print {
+		case "stdout":
+			data.Rows[t.rIndex].Columns[t.cIndex] = stdout
+		case "stderr":
+			data.Rows[t.rIndex].Columns[t.cIndex] = fmt.Sprintf("%s\n%s", stderr, err.Error())
+		default:
+			data.Rows[t.rIndex].Columns[t.cIndex] = fmt.Sprintf("%s\n%s", out, err.Error())
+		}
 	} else {
-		data.Rows[t.rIndex].Columns[t.cIndex] = strings.TrimSuffix(out, "\n")
+		switch r.Task.Spec.Print {
+		case "stdout":
+			data.Rows[t.rIndex].Columns[t.cIndex] = stdout
+		case "stderr":
+			data.Rows[t.rIndex].Columns[t.cIndex] = stderr
+		default:
+			data.Rows[t.rIndex].Columns[t.cIndex] = strings.TrimSuffix(out, "\n")
+		}
 	}
 
 	reportData.Tasks[r.i].Rows[r.j].ReturnCode = errCode
@@ -604,3 +633,24 @@ func runTableCmd(i int, t TaskContext, wg *sync.WaitGroup) (string, string, stri
 
 	return buf.String(), bufOut.String(), bufErr.String(), nil
 }
+
+func getServerTitle(client Client, i int, ts dao.Table) (string, error) {
+	if ts.Prefix == "" {
+		return "", nil
+	}
+
+	name, host, user, port := client.Prefix()
+	data := PrefixData{
+		Name:  name,
+		Host:  host,
+		User:  user,
+		Port:  port,
+		Index: i,
+	}
+	prefix, err := PrefixTemplate(ts.Prefix, data)
+	if err != nil {
+		return "", err
+	}
+
+	return prefix, nil
+}
